/**
 * Tribe: Group communication library.
 * Copyright (C) 2004-2005 French National Institute For Research In Computer
 * Science And Control (INRIA).
 * Contact: tribe@objectweb.org
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by the
 * Free Software Foundation; either version 2.1 of the License, or any later
 * version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *
 * Initial developer(s): Emmanuel Cecchet.
 * Contributor(s): ______________________.
 */

package org.objectweb.tribe.adapters;

import java.io.Serializable;
import java.util.ArrayList;

import org.objectweb.tribe.common.Member;
import org.objectweb.tribe.common.log.Trace;

/**
 * This class defines a MulticastRequestAdapterThread
 * 
 * @author <a href="mailto:Emmanuel.Cecchet@inria.fr">Emmanuel Cecchet </a>
 * @version 1.0
 */
public class MulticastRequestAdapterThread extends Thread
{

  private MulticastRequestListener       multicastRequestListener;
  private PullPushAdapter                pullPushAdapter;
  private MulticastRequestAdapterMessage requestReply;
  private Object                         singleTheadedCallback;
  private Member                         me;
  private static Trace                   logger = Trace
                                                    .getLogger("org.objectweb.tribe.blocks.multicastdispatcher");

  /**
   * Creates a new <code>MulticastRequestAdapterThread</code> object
   * 
   * @param listener the multicastRequestListener to call
   * @param requestReply the request to handle
   * @param singleTheadedCallback result from handleMessageSingleThreaded
   * @param pullPushAdapter pullPushAdapter for sending the reply
   * @param senderMembership membership of the sender
   */
  public MulticastRequestAdapterThread(MulticastRequestListener listener,
      MulticastRequestAdapterMessage requestReply,
      Object singleTheadedCallback, PullPushAdapter pullPushAdapter,
      Member senderMembership)
  {
    super("MulticastRequestAdapterThread");
    this.multicastRequestListener = listener;
    this.requestReply = requestReply;
    this.singleTheadedCallback = singleTheadedCallback;
    this.me = senderMembership;
    this.pullPushAdapter = pullPushAdapter;
  }

  /**
   * Delivers the message to the listener and send back the response.
   */
  public void run()
  {
    Member replyTo = requestReply.getSender();

    Serializable reply = multicastRequestListener.handleMessageMultiThreaded(
        requestReply.getMessage(), replyTo, singleTheadedCallback);
    if (!requestReply.isRequestOnly())
    {
      // We cannot reuse the same object in case multiple receivers are in the
      // same virtual machine and the message was not delivered yet to the
      // other receivers (they would receive the reply instead of the request
      // if we call requestReply.setReply()).
      MulticastRequestAdapterMessage answer = new MulticastRequestAdapterMessage(
          reply, me, requestReply.getUid(),
          MulticastRequestAdapterMessage.REPLY);
      ArrayList replyList = new ArrayList(1);
      replyList.add(replyTo);
      try
      {
        if (logger.isDebugEnabled())
          logger.debug("Replying to " + replyTo + " for message "
              + requestReply.getUid());
        pullPushAdapter.send(answer, replyList);
      }
      catch (Exception e)
      {
        logger
            .info("Error while replying to " + replyTo + " for message "
                + requestReply.getUid() + " (" + requestReply.getMessage()
                + ")", e);
      }
    }
  }

}