/**
 * Tribe: Group communication library.
 * Copyright (C) 2004 French National Institute For Research In Computer
 * Science And Control (INRIA).
 * Contact: tribe@objectweb.org
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by the
 * Free Software Foundation; either version 2.1 of the License, or any later
 * version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *
 * Initial developer(s): Emmanuel Cecchet.
 * Contributor(s): ______________________.
 */

package org.objectweb.tribe.channel;

import org.objectweb.tribe.common.Address;
import org.objectweb.tribe.exceptions.ChannelException;
import org.objectweb.tribe.exceptions.NotConnectedException;
import org.objectweb.tribe.messages.ChannelMessage;

/**
 * This interface defines a AbstractReliableFifoChannel
 * 
 * @author <a href="mailto:Emmanuel.Cecchet@inria.fr">Emmanuel Cecchet </a>
 * @version 1.0
 */
public abstract class AbstractReliableFifoChannel
{

  /**
   * Connects to the given endpoint.
   * 
   * @param destination endpoint to connect to.
   * @throws ChannelException if an error occurs.
   */
  public abstract void connect(Address destination) throws ChannelException;

  /**
   * Sends a message on the channel.
   * 
   * @param msg the message to send
   * @throws ChannelException if an error occurs.
   * @throws NotConnectedException if the channel is not connected
   */
  public abstract void send(ChannelMessage msg) throws ChannelException,
      NotConnectedException;

  /**
   * Closes the channel.
   * 
   * @throws ChannelException if an error occurs.
   */
  public abstract void close() throws ChannelException;

  /**
   * Get the source endpoint of this channel.
   * 
   * @return the source address
   */
  public abstract Address getSourceAddress() throws ChannelException;

  /**
   * Get the destination endpoint of this channel.
   * 
   * @return the destination address
   */
  public abstract Address getDestinationAddress() throws ChannelException;

}