/**
 * Tribe: Group communication library.
 * Copyright (C) 2004 French National Institute For Research In Computer
 * Science And Control (INRIA).
 * Contact: tribe@objectweb.org
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by the
 * Free Software Foundation; either version 2.1 of the License, or any later
 * version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *
 * Initial developer(s): Emmanuel Cecchet.
 * Contributor(s): ______________________.
 */

package org.objectweb.tribe.channel;

import org.objectweb.tribe.common.Address;
import org.objectweb.tribe.exceptions.ChannelException;
import org.objectweb.tribe.exceptions.NotConnectedException;

/**
 * This class defines a AbstractServerChannel to accept new connections.
 * 
 * @author <a href="mailto:Emmanuel.Cecchet@inria.fr">Emmanuel Cecchet </a>
 * @version 1.0
 */
public abstract class AbstractServerChannel
{

  /**
   * Binds a source address
   * 
   * @param source source address to bind
   * @throws ChannelException if an error occurs
   */
  public abstract void bind(Address source) throws ChannelException;

  /**
   * Accepts a new incoming connection.
   * 
   * @return the new serverSocket
   * @throws ChannelException if an error occurs
   */
  public abstract AbstractReliableFifoChannel accept() throws ChannelException;

  /**
   * Get the address on which this channel is bound.
   * 
   * @throws NotConnectedException if the channel is not connected.
   */
  public abstract Address getBindAddress() throws NotConnectedException;

  /**
   * Closes the serverSocket.
   * 
   * @throws ChannelException if an error occurs.
   */
  public abstract void close() throws ChannelException;

}