/**
 * Tribe: Group communication library.
 * Copyright (C) 2002-2004 French National Institute For Research In Computer
 * Science And Control (INRIA).
 * Contact: tribe@objectweb.org
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by the
 * Free Software Foundation; either version 2.1 of the License, or any later
 * version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *
 * Initial developer(s): Emmanuel Cecchet.
 * Contributor(s): ______________________.
 */

package org.objectweb.tribe.channel;

import java.util.ArrayList;

import org.objectweb.tribe.common.Address;
import org.objectweb.tribe.common.Group;
import org.objectweb.tribe.common.GroupIdentifier;
import org.objectweb.tribe.common.Member;
import org.objectweb.tribe.gms.GroupMembershipListener;
import org.objectweb.tribe.gms.GroupMembershipService;
import org.objectweb.tribe.views.View;
import org.objectweb.tribe.views.ViewListener;

/**
 * This class defines a ReliableGroupChannelWithViews. It is built on top of a
 * ReliableGroupChannelWithGms to which it adds view synchrony.
 * 
 * @author <a href="mailto:Emmanuel.Cecchet@inria.fr">Emmanuel Cecchet </a>
 * @version 1.0
 */
public class ReliableGroupChannelWithViews extends ReliableGroupChannelWithGms
    implements
      GroupMembershipListener
{
  private View      currentView;
  private ArrayList listeners;

  /**
   * Creates a new <code>ReliableGroupChannelWithViews</code> object
   * 
   * @param gms The GroupMembershipService to use
   */
  public ReliableGroupChannelWithViews(GroupMembershipService gms)
  {
    super(gms);
    gms.registerGroupMembershipListener(this);
    listeners = new ArrayList();
  }

  /**
   * Register a new ViewListener.
   * 
   * @param listener the listener to register
   */
  public void registerViewListener(ViewListener listener)
  {
    synchronized (listener)
    {
      listeners.add(listener);
    }
  }

  /**
   * Unregister a view ViewListener.
   * 
   * @param listener the listener to unregister
   */
  public void unregisterViewListener(ViewListener listener)
  {
    synchronized (listener)
    {
      listeners.remove(listener);
    }
  }

  //
  // GroupMembershipListener interface
  //

  /**
   * @see org.objectweb.tribe.gms.GroupMembershipListener#joinMember(org.objectweb.tribe.common.Member,
   *      org.objectweb.tribe.common.GroupIdentifier)
   */
  public void joinMember(Member m, GroupIdentifier gid)
  {
    // TODO Auto-generated method stub

  }

  /**
   * @see org.objectweb.tribe.gms.GroupMembershipListener#quitMember(org.objectweb.tribe.common.Member,
   *      org.objectweb.tribe.common.GroupIdentifier)
   */
  public void quitMember(Member m, GroupIdentifier gid)
  {
    // TODO Auto-generated method stub

  }

  /**
   * @see org.objectweb.tribe.gms.GroupMembershipListener#groupComposition(org.objectweb.tribe.common.Group,
   *      org.objectweb.tribe.common.Address)
   */
  public void groupComposition(Group g, Address sender)
  {
    // TODO Auto-generated method stub

  }

  /**
   * @see org.objectweb.tribe.gms.GroupMembershipListener#failedMember(org.objectweb.tribe.common.Member,
   *      org.objectweb.tribe.common.GroupIdentifier,
   *      org.objectweb.tribe.common.Member)
   */
  public void failedMember(Member failed, GroupIdentifier gid, Member sender)
  {
    // TODO Auto-generated method stub

  }
}