/**
 * Tribe: Group communication library.
 * Copyright (C) 2004 French National Institute For Research In Computer
 * Science And Control (INRIA).
 * Contact: tribe@objectweb.org
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by the
 * Free Software Foundation; either version 2.1 of the License, or any later
 * version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *
 * Initial developer(s): Emmanuel Cecchet.
 * Contributor(s): ______________________.
 */

package org.objectweb.tribe.common;

import java.io.Serializable;

/**
 * This class defines a GroupIdentifier
 * 
 * @author <a href="mailto:Emmanuel.Cecchet@inria.fr">Emmanuel Cecchet </a>
 * @version 1.0
 */
public class GroupIdentifier implements Serializable
{
  private String groupName;

  /**
   * Creates a new <code>GroupIdentifier</code> object from a given group
   * name.
   */
  public GroupIdentifier(String groupName)
  {
    this.groupName = groupName;
  }

  /**
   * Get the group name as given in the constructor.
   */
  public String getGroupName()
  {
    return groupName;
  }

  /**
   * @see java.lang.Object#toString()
   */
  public String toString()
  {
    return groupName;
  }

  /**
   * @see java.lang.Object#equals(java.lang.Object)
   */
  public boolean equals(Object obj)
  {
    if (obj instanceof GroupIdentifier)
      return groupName.equals(((GroupIdentifier) obj).getGroupName());
    else
      return false;
  }

  /**
   * @see java.lang.Object#hashCode()
   */
  public int hashCode()
  {
    return groupName.hashCode();
  }
  
}