/**
 * Tribe: Group communication library.
 * Copyright (C) 2004 French National Institute For Research In Computer
 * Science And Control (INRIA).
 * Contact: tribe@objectweb.org
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by the
 * Free Software Foundation; either version 2.1 of the License, or any later
 * version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *
 * Initial developer(s): Emmanuel Cecchet.
 * Contributor(s): ______________________.
 */

package org.objectweb.tribe.common;

import java.net.InetAddress;

/**
 * This class defines an IpAddress
 * 
 * @author <a href="mailto:Emmanuel.Cecchet@inria.fr">Emmanuel Cecchet </a>
 * @version 1.0
 */
public class IpAddress implements Address
{

  private InetAddress address;
  private int         port;

  /**
   * Creates a new <code>IpAddress</code> object
   */
  public IpAddress(InetAddress address, int port)
  {
    this.address = address;
    this.port = port;
  }

  /**
   * Returns the address value.
   * 
   * @return Returns the address.
   */
  public InetAddress getAddress()
  {
    return address;
  }

  /**
   * Sets the address value.
   * 
   * @param address The address to set.
   */
  public void setAddress(InetAddress address)
  {
    this.address = address;
  }

  /**
   * Sets the port value.
   * 
   * @param port The port to set.
   */
  public void setPort(int port)
  {
    this.port = port;
  }

  /**
   * Returns the port value.
   * 
   * @return Returns the port.
   */
  public int getPort()
  {
    return port;
  }

  /**
   * @see java.lang.Object#toString()
   */
  public String toString()
  {
    return address.toString() + ":" + port;
  }

  /**
   * @see java.lang.Object#equals(java.lang.Object)
   */
  public boolean equals(Object obj)
  {
    if (obj instanceof IpAddress)
    {
      IpAddress ip = (IpAddress) obj;
      return (this.port == ip.port)
          && (((this.getAddress() == null) && (ip.getAddress() == null)) || this
              .getAddress().equals(ip.getAddress()));
    }
    return false;
  }

  /**
   * @see java.lang.Object#hashCode()
   */
  public int hashCode()
  {
    return address.hashCode() + port;
  }

  /**
   * @see java.lang.Comparable#compareTo(java.lang.Object)
   */
  public int compareTo(Object o)
  {
    if (o instanceof IpAddress)
      return address.toString().compareTo(
          ((IpAddress) o).getAddress().toString());
    else
      throw new ClassCastException(
          "IpAddress can only be compared with another IpAddress");
  }

}