/**
 * Tribe: Group communication library.
 * Copyright (C) 2004 French National Institute For Research In Computer
 * Science And Control (INRIA).
 * Contact: tribe@objectweb.org
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by the
 * Free Software Foundation; either version 2.1 of the License, or any later
 * version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *
 * Initial developer(s): Emmanuel Cecchet.
 * Contributor(s): Nicolas Modrzyk.
 */

package org.objectweb.tribe.common;

import java.io.Serializable;

/**
 * This class defines a group Member.
 * 
 * @author <a href="mailto:Emmanuel.Cecchet@inria.fr">Emmanuel Cecchet </a>
 * @author <a href="mailto:Nicolas.Modrzyk@inrialpes.fr">Nicolas Modrzyk </a>
 * @version 1.0
 */
public class Member implements Serializable
{
  private Address address;
  private String  uid;

  /**
   * Creates a new <code>Member</code> object
   * 
   * @param address member address
   * @param uid member unique identifier
   */
  public Member(Address address, String uid)
  {
    this.address = address;
    this.uid = uid;
  }

  /**
   * Returns the address value.
   * 
   * @return Returns the address.
   */
  public Address getAddress()
  {
    return address;
  }

  /**
   * Sets the address value.
   * 
   * @param address The address to set.
   */
  public void setAddress(Address address)
  {
    this.address = address;
  }

  /**
   * Returns the uid value.
   * 
   * @return Returns the uid.
   */
  public String getUid()
  {
    return uid;
  }

  /**
   * Sets the uid value.
   * 
   * @param uid The uid to set.
   */
  public void setUid(String uid)
  {
    this.uid = uid;
  }

  /**
   * @see java.lang.Object#equals(java.lang.Object)
   */
  public boolean equals(Object obj)
  {
    if (obj instanceof Member)
    {
      Member m = (Member) obj;
      return uid.equals(m.uid) && address.equals(m.address);
    }
    return false;
  }

  /**
   * @see java.lang.Object#hashCode()
   */
  public int hashCode()
  {
    return uid.hashCode() + address.hashCode();
  }

  /**
   * @see java.lang.Object#toString()
   */
  public String toString()
  {
    return uid + "[" + address + "]";
  }

}