/**
 * Tribe: Group communication library.
 * Copyright (C) 2004 French National Institute For Research In Computer
 * Science And Control (INRIA).
 * Contact: tribe@objectweb.org
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by the
 * Free Software Foundation; either version 2.1 of the License, or any later
 * version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *
 * Initial developer(s): Nicolas Modrzyk.
 * Contributor(s): ______________________.
 */

package org.objectweb.tribe.faultdetection;

import org.objectweb.tribe.common.Address;

/**
 * Call back listener interface for the ping service
 * 
 * @author <a href="mailto:Nicolas.Modrzyk@inrialpes.fr">Nicolas Modrzyk </a>
 * @version 1.0
 */
public interface FaultDetectionListener
{

  /**
   * UDPPingThread thread was interrupted
   */
  public static final int EVENT_INTERRUPTED         = 0;

  /**
   * UDPPingThread thread is quitting
   */
  public static final int EVENT_QUIT                = 1;

  /**
   * UDPPingThread thread cannot access local address
   */
  public static final int EVENT_ERROR_LOCAL_ADDRESS = 2;

  /** Thread is responding to ping */
  public static final int THREAD_ALIVE              = 10;

  /** Thread did not respond to last ping */
  public static final int THREAD_SUSPECTED          = 11;

  /** Thread contact was lost */
  public static final int THREAD_LOST               = 12;

  /**
   * Notifify that the <code>Address</code> is suspected of failure
   * 
   * @param address <code>Address</code> suspected
   */
  void suspect(Address address);

  /**
   * Notify that the <code>Address</code> did not respond to the last ping
   * 
   * @param address <code>Address</code> that did not respond
   */
  void noResponse(Address address);

  /**
   * Notify that this was the lastPing on the <code>Address</code>
   * 
   * @param address
   */
  void lastPing(Address address);

  /**
   * Something special has occured to the ping service: the thread was
   * interrupted, the service was stopped ...
   * 
   * @param event an id of the event that happened
   */
  void pingServiceEvent(int event);

  /**
   * Notify that the given address is alive
   * 
   * @param address 
   */
  void alive(Address address);

}