/**
 * Tribe: Group communication library.
 * Copyright (C) 2004 French National Institute For Research In Computer
 * Science And Control (INRIA).
 * Contact: tribe@objectweb.org
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by the
 * Free Software Foundation; either version 2.1 of the License, or any later
 * version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *
 * Initial developer(s): Nicolas Modrzyk.
 * Contributor(s): ______________________.
 */

package org.objectweb.tribe.faultdetection;

import java.io.IOException;
import java.net.DatagramPacket;
import java.net.DatagramSocket;
import java.net.SocketException;

import org.objectweb.tribe.common.IpAddress;
import org.objectweb.tribe.messages.DatagramMessage;

/**
 * This class defines a UDPPingThread. This defines a Ping thread that can be use and reuse to ping a target IpAddress
 * 
 * @author <a href="mailto:Nicolas.Modrzyk@inrialpes.fr">Nicolas Modrzyk</a>
 * @version 1.0
 */
public class UDPPingThread extends Thread
{

  IpAddress target;
  IpAddress src;
  int timeout;
  boolean alive;
  DatagramSocket socket;
  DatagramMessage message;
  DatagramPacket packet;
  
  /**
   * Creates a new <code>UDPPingThread</code> object
   * @throws SocketException
   * 
   * 
   */
  public UDPPingThread(IpAddress target,IpAddress src,int timeout) throws SocketException
  {
    super("UDP Ping Thread");
    this.target = target;
    this.src = src;
    this.timeout = timeout;
    socket = new DatagramSocket(src.getPort());
    socket.setSoTimeout(timeout);
    message = new DatagramMessage(src,target);
    message.setContent(new String("Iamaping").getBytes());
    packet = message.getDatagramPacket();
  }

  /**
   * @see java.lang.Runnable#run()
   */
  public void run()
  {
    try
    {
      alive = true;
      socket.send(packet);
      // Wait only for the time specified by timeout
      socket.receive(packet);
    }
    catch (IOException e)
    {
      alive = false;
    }
  }

  /**
   * Returns the alive value.
   * 
   * @return Returns the alive.
   */
  public boolean isTargetAlive()
  {
    return alive;
  }
}
