/**
 * Tribe: Group communication library.
 * Copyright (C) 2004 French National Institute For Research In Computer
 * Science And Control (INRIA).
 * Contact: tribe@objectweb.org
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by the
 * Free Software Foundation; either version 2.1 of the License, or any later
 * version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *
 * Initial developer(s): Nicolas Modrzyk.
 * Contributor(s): ______________________.
 */

package org.objectweb.tribe.faultdetection;

import java.io.IOException;
import java.net.DatagramSocket;

import org.objectweb.tribe.common.IpAddress;
import org.objectweb.tribe.messages.DatagramMessage;

/**
 * This class defines a UDPPongThread. Send an echo message
 * 
 * @author <a href="mailto:Nicolas.Modrzyk@inrialpes.fr">Nicolas Modrzyk </a>
 * @version 1.0
 */
public class UDPPongThread implements Runnable
{
  private IpAddress src;
  private IpAddress target;
  private boolean   quit;

  /**
   * Creates a new <code>UDPPongThread</code> object
   * 
   * @param src
   * @param target
   */
  public UDPPongThread(IpAddress src, IpAddress target)
  {
    super();
    this.src = src;
    this.target = target;
  }

  /**
   * @see java.lang.Runnable#run()
   */
  public void run()
  {
    DatagramSocket socket = null;
    while (!quit)
    {
      try
      {
        socket = new DatagramSocket(src.getPort());
        DatagramMessage message = new DatagramMessage(src, target);
        socket.receive(message.getDatagramPacket());
        socket.send(message.getDatagramPacket());
        socket.close();
      }
      catch (IOException e)
      {
        e.printStackTrace();
        if (socket != null)
          socket.close();
      }

    }
  }

  /**
   * Sets the quit value.
   * 
   * @param quit The quit to set.
   */
  public void setQuit(boolean quit)
  {
    this.quit = quit;
  }
}