/**
 * Tribe: Group communication library.
 * Copyright (C) 2004 French National Institute For Research In Computer
 * Science And Control (INRIA).
 * Contact: tribe@objectweb.org
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by the
 * Free Software Foundation; either version 2.1 of the License, or any later
 * version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *
 * Initial developer(s): Emmanuel Cecchet.
 * Contributor(s): ______________________.
 */

package org.objectweb.tribe.gms;

import org.objectweb.tribe.common.Address;
import org.objectweb.tribe.common.Group;
import org.objectweb.tribe.common.GroupIdentifier;
import org.objectweb.tribe.common.Member;

/**
 * This interface defines a GroupMembershipListener
 * 
 * @author <a href="mailto:Emmanuel.Cecchet@inria.fr">Emmanuel Cecchet </a>
 * @version 1.0
 */
public interface GroupMembershipListener
{

  /**
   * Callback when a new member joins a group.
   * 
   * @param m the new member.
   * @param gid the group identifier
   */
  void joinMember(Member m, GroupIdentifier gid);

  /**
   * Callback when a member leaves a group (intentionally or not).
   * 
   * @param m the member who left the group.
   * @param gid the group identifier
   */
  void quitMember(Member m, GroupIdentifier gid);

  /**
   * Callback when a member sends its view of a group composition.
   * 
   * @param g the group composition
   * @param sender the member sending the group information
   */
  void groupComposition(Group g, Address sender);

  /**
   * Callback when a group member is suspected of failure.
   * 
   * @param failed the member suspected of failure
   * @param gid group identifier
   * @param sender message sender (reporting the failure)
   */
  void failedMember(Member failed, GroupIdentifier gid, Member sender);

}