/**
 * Tribe: Group communication library.
 * Copyright (C) 2004 French National Institute For Research In Computer
 * Science And Control (INRIA).
 * Contact: tribe@objectweb.org
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by the
 * Free Software Foundation; either version 2.1 of the License, or any later
 * version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *
 * Initial developer(s): Emmanuel Cecchet.
 * Contributor(s): ______________________.
 */

package org.objectweb.tribe.gms.protocol;

import org.objectweb.tribe.common.GroupIdentifier;
import org.objectweb.tribe.common.IpAddress;
import org.objectweb.tribe.messages.DatagramMessage;

/**
 * This class defines a GroupDiscoveryMessage
 * 
 * @author <a href="mailto:Emmanuel.Cecchet@inria.fr">Emmanuel Cecchet </a>
 * @version 1.0
 */
public class GroupDiscoveryMessage extends DatagramMessage
{
  private GroupIdentifier groupIdentifier;

  /**
   * Creates a new <code>GroupDiscoveryMessage</code> object used to join a group by
   * the Group Membership Service.
   * 
   * @param src source address
   * @param dest destination address
   * @param gid group identifier
   */
  public GroupDiscoveryMessage(IpAddress src, IpAddress dest, GroupIdentifier gid)
  {
    super(src, dest);
    this.groupIdentifier = gid;
    this.setContent(objectToBytes(this));
  }

  /**
   * Returns the groupIdentifier value.
   * 
   * @return Returns the groupIdentifier.
   */
  public GroupIdentifier getGroupIdentifier()
  {
    return groupIdentifier;
  }

}