/**
 * Tribe: Group communication library.
 * Copyright (C) 2002-2004 French National Institute For Research In Computer
 * Science And Control (INRIA).
 * Contact: tribe@objectweb.org
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by the
 * Free Software Foundation; either version 2.1 of the License, or any later
 * version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *
 * Initial developer(s): Emmanuel Cecchet.
 * Contributor(s): ______________________.
 */

package org.objectweb.tribe.messages;

import java.io.Serializable;

/**
 * This class defines a ByteMessage
 * 
 * @author <a href="mailto:Emmanuel.Cecchet@inria.fr">Emmanuel Cecchet </a>
 * @version 1.0
 */
public class ByteMessage implements Serializable
{

  private byte[] content;

  /**
   * Creates a new <code>ByteMessage</code> object
   * 
   * @param msg the new message content
   */
  public ByteMessage(byte[] msg)
  {
    this.content = msg;
  }

  /**
   * Returns the content value.
   * 
   * @return Returns the content.
   */
  public byte[] getContent()
  {
    return content;
  }

  /**
   * Set the message content (overrides any previous content).
   * 
   * @param msg the new message content
   */
  protected void setContent(byte[] msg)
  {
    this.content = msg;
  }
}