/**
 * Tribe: Group communication library.
 * Copyright (C) 2002-2005 French National Institute For Research In Computer
 * Science And Control (INRIA).
 * Contact: tribe@objectweb.org
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by the
 * Free Software Foundation; either version 2.1 of the License, or any later
 * version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *
 * Initial developer(s): Emmanuel Cecchet.
 * Contributor(s): ______________________.
 */

package org.objectweb.tribe.messages;

/**
 * This class defines a FragmentedMessage to be used as a facility to send a
 * large message in smaller chunks if the underlying network is not capable of
 * fragmentation.
 * 
 * @author <a href="mailto:Emmanuel.Cecchet@inria.fr">Emmanuel Cecchet </a>
 * @version 1.0
 */
public class FragmentedMessage extends ByteMessage
{

  private String messageId;
  private int    size;
  private int    fragmentId;

  /**
   * Creates a new <code>FragmentedMessage</code> object
   * 
   * @param messageSize the overall message size
   */
  public FragmentedMessage(int messageSize)
  {
    super(null);
    this.messageId = toString(); // Dirty hack here
    this.size = messageSize;
    this.fragmentId = 0;
  }

  /**
   * Return the fragment data
   * 
   * @return byte array containing the fragment data
   */
  public byte[] getFragmentData()
  {
    return getContent();
  }

  /**
   * Get the identifier of this fragment
   * 
   * @return fragment number
   */
  public int getFragmentId()
  {
    return fragmentId;
  }

  /**
   * Return the message identifier
   * 
   * @return message identifier
   */
  public String getMessageId()
  {
    return messageId;
  }

  /**
   * Get the total message size (for all fragments)
   * 
   * @return overall message size
   */
  public int getMessageSize()
  {
    return size;
  }

  /**
   * Sets the next fragment in the message
   * 
   * @param fragmentId fragment number
   * @param buf fragment data
   */
  public void setFragment(int fragmentId, byte[] buf)
  {
    this.fragmentId = fragmentId;
    setContent(buf);
  }

}