/**
 * Tribe: Group communication library.
 * Copyright (C) 2002-2004 French National Institute For Research In Computer
 * Science And Control (INRIA).
 * Contact: tribe@objectweb.org
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by the
 * Free Software Foundation; either version 2.1 of the License, or any later
 * version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *
 * Initial developer(s): Emmanuel Cecchet.
 * Contributor(s): ______________________.
 */

package org.objectweb.tribe.views;

import java.util.ArrayList;

/**
 * This class defines a View of a group. This is used for view synchrony.
 * 
 * @author <a href="mailto:Emmanuel.Cecchet@inria.fr">Emmanuel Cecchet </a>
 * @version 1.0
 */
public class View
{
  /** Unique identifier of the view */
  private int       viewId;
  private ArrayList members;

  /**
   * Creates a new view
   * 
   * @param viewId The view uniaque identifier
   * @param members Contains a list of all the members in the view, can be empty
   *          but not null.
   */
  public View(int viewId, ArrayList members)
  {
    this.viewId = viewId;
    this.members = members;
  }

  /**
   * Returns a reference to the list of members (this list may have been ordered
   * by the underlying GMS service). Make a copy of the list if you have to
   * modify it.
   * 
   * @return a reference to the ordered list of members in this view
   */
  public ArrayList getMembers()
  {
    return members;
  }

  /**
   * Returns the id of this view.
   * 
   * @return Returns the view id.
   */
  public int getViewId()
  {
    return viewId;
  }
}