/**
 * Tribe: Group communication library.
 * Copyright (C) 2004 French National Institute For Research In Computer
 * Science And Control (INRIA).
 * Contact: tribe@objectweb.org
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by the
 * Free Software Foundation; either version 2.1 of the License, or any later
 * version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *
 * Initial developer(s): Emmanuel Cecchet.
 * Contributor(s): ______________________.
 */

package org.objectweb.tribe.channel;

import java.net.InetAddress;

import junit.framework.TestCase;

import org.objectweb.tribe.channel.tcp.TcpChannelPool;
import org.objectweb.tribe.common.GroupIdentifier;
import org.objectweb.tribe.common.IpAddress;
import org.objectweb.tribe.exceptions.AlreadyMemberException;
import org.objectweb.tribe.exceptions.ChannelException;
import org.objectweb.tribe.exceptions.NotConnectedException;
import org.objectweb.tribe.gms.GroupMembershipService;
import org.objectweb.tribe.gms.discovery.UdpDiscoveryService;

/**
 * This class defines a ReliableGroupChannelTest
 * 
 * @author <a href="mailto:Emmanuel.Cecchet@inria.fr">Emmanuel Cecchet </a>
 * @version 1.0
 */
public class ReliableGroupChannelTest extends TestCase
{

  private ReliableGroupChannelWithGms channel1;
  private ReliableGroupChannelWithGms channel2;
  private final GroupIdentifier       gid1 = new GroupIdentifier("group1");
  private final String                msg1 = "Hello from 1";
  private final String                msg2 = "Hello from 2";

  /*
   * @see TestCase#setUp()
   */
  protected void setUp() throws Exception
  {
    final InetAddress MULTICAST_ADDRESS = InetAddress.getByName("224.7.65.23");
    final int MULTICAST_PORT = 2288;
    final IpAddress MULTICAST_IP = new IpAddress(MULTICAST_ADDRESS,
        MULTICAST_PORT);
    final InetAddress REPLY_ADDRESS = InetAddress.getLocalHost();
    final int REPLY_PORT = 12345;
    final IpAddress REPLY_IP = new IpAddress(REPLY_ADDRESS, REPLY_PORT);

    UdpDiscoveryService discovery = new UdpDiscoveryService(MULTICAST_IP,
        REPLY_IP);
    GroupMembershipService gms = new GroupMembershipService(REPLY_IP,
        TcpChannelPool.getChannelPool(), discovery);
    discovery.start();
    channel1 = new ReliableGroupChannelWithGms(gms);
    channel2 = new ReliableGroupChannelWithGms(gms);
  }

  /**
   * Test the group join/send/receive/quit primitives
   */
  public void testJoinSendReceiveQuit()
  {
    // Join

    try
    {
      channel1.join(gid1);
    }
    catch (AlreadyMemberException e)
    {
      e.printStackTrace();
      fail("Failed to join group for channel1");
    }
    catch (ChannelException e)
    {
      e.printStackTrace();
      fail("Failed to join group for channel1");
    }
    catch (NotConnectedException e)
    {
      e.printStackTrace();
      fail("Failed to join group for channel1");
    }
    try
    {
      channel2.join(gid1);
    }
    catch (AlreadyMemberException e)
    {
      e.printStackTrace();
      fail("Failed to join group for channel1");
    }
    catch (ChannelException e)
    {
      e.printStackTrace();
      fail("Failed to join group for channel1");
    }
    catch (NotConnectedException e)
    {
      e.printStackTrace();
      fail("Failed to join group for channel1");
    }

    // Sleep 2 seconds

    try
    {
      Thread.sleep(2000);
    }
    catch (InterruptedException e4)
    {
      e4.printStackTrace();
    }

    // Send

    try
    {
      channel1.send(msg1);
    }
    catch (Exception e1)
    {
      e1.printStackTrace();
      fail("Unable to send message on channel1");
    }
    try
    {
      channel2.send(msg2);
    }
    catch (Exception e1)
    {
      e1.printStackTrace();
      fail("Unable to send message on channel2");
    }

    // Receive

    try
    {
      assertEquals(msg1, channel1.receive());
      assertEquals(msg2, channel1.receive());
    }
    catch (Exception e2)
    {
      e2.printStackTrace();
      fail("Failed to receive message on channel1");
    }
    try
    {
      assertEquals(msg1, channel2.receive());
      assertEquals(msg2, channel2.receive());
    }
    catch (Exception e2)
    {
      e2.printStackTrace();
      fail("Failed to receive message on channel2");
    }

    // Quit

    try
    {
      channel1.quit();
    }
    catch (Exception e3)
    {
      e3.printStackTrace();
      fail("Failed to quit group for channel1");
    }
    try
    {
      channel2.quit();
    }
    catch (Exception e3)
    {
      e3.printStackTrace();
      fail("Failed to quit group for channel2");
    }
  }
}