/**
 * Tribe: Group communication library.
 * Copyright (C) 2004 French National Institute For Research In Computer
 * Science And Control (INRIA).
 * Contact: tribe@objectweb.org
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by the
 * Free Software Foundation; either version 2.1 of the License, or any later
 * version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *
 * Initial developer(s): Bela Ban.
 * Contributor(s): Emmanuel Cecchet.
 */

package org.objectweb.tribe.demos.draw;

import java.io.Serializable;

/**
 * This class defines a WhiteBoardCommand. It is used either for drawing a point
 * or clearing the display. One should have used 2 separate classes since it is
 * useless to transport point information just for a clear command, but I have
 * just reused the code from the JGroups demo.
 * 
 * @author Bela Ban, 2001
 * @author <a href="mailto:Emmanuel.Cecchet@inria.fr">Emmanuel Cecchet </a>
 * @version 1.0
 */
public class WhiteBoardCommand implements Serializable
{
  static final int DRAW  = 1;
  static final int CLEAR = 2;
  int              mode;
  int              x     = 0;
  int              y     = 0;
  int              r     = 0;
  int              g     = 0;
  int              b     = 0;

  /**
   * Creates a new <code>WhiteBoardCommand</code> object for clearing the
   * display.
   */
  WhiteBoardCommand()
  {
    this.mode = CLEAR;
  }

  /**
   * Creates a new <code>WhiteBoardCommand</code> object to draw a point.
   * 
   * @param x x coordinate of the point
   * @param y y coordinate of the point
   * @param r red color
   * @param g green color
   * @param b blue color
   */
  WhiteBoardCommand(int x, int y, int r, int g, int b)
  {
    this.mode = DRAW;
    this.x = x;
    this.y = y;
    this.r = r;
    this.g = g;
    this.b = b;
  }

  /**
   * Copy this object.
   * 
   * @return A new instance of this object.
   */
  WhiteBoardCommand Copy()
  {
    if (mode == CLEAR)
      return new WhiteBoardCommand();
    else
      return new WhiteBoardCommand(x, y, r, g, b);
  }

  /**
   * @see java.lang.Object#toString()
   */
  public String toString()
  {
    StringBuffer ret = new StringBuffer();
    switch (mode)
    {
      case DRAW :
        ret
            .append("DRAW(" + x + ", " + y + ") [" + r + "|" + g + "|" + b
                + "]");
        break;
      case CLEAR :
        ret.append("CLEAR");
        break;
      default :
        return "<undefined>";
    }
    return ret.toString();
  }

}